Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(144)

Unified Diff: net/url_request/url_request_redirect_job.h

Issue 5607004: net: Remove typedef net::URLRequestJob URLRequestJob; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebased Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/url_request/url_request_redirect_job.h
diff --git a/net/url_request/url_request_redirect_job.h b/net/url_request/url_request_redirect_job.h
index 7466cec07fc95cdb9cc3b0c8ccb80c365dafcefb..d81d7e6ec34f329e55d67d2392f5c9694a3dfe99 100644
--- a/net/url_request/url_request_redirect_job.h
+++ b/net/url_request/url_request_redirect_job.h
@@ -10,10 +10,10 @@
class GURL;
// A URLRequestJob that will redirect the request to the specified
// URL. This is useful to restart a request at a different URL based
// on the result of another job.
-class URLRequestRedirectJob : public URLRequestJob {
+class URLRequestRedirectJob : public net::URLRequestJob {
public:
// Constructs a job that redirects to the specified URL.
URLRequestRedirectJob(net::URLRequest* request, GURL redirect_destination);
@@ -10,10 +10,10 @@
class GURL;
-// A URLRequestJob that will redirect the request to the specified
+// A net::URLRequestJob that will redirect the request to the specified
// URL. This is useful to restart a request at a different URL based
// on the result of another job.

Powered by Google App Engine
This is Rietveld 408576698